pub struct Time(pub Time);Expand description
An ICU4X Time object representing a time in terms of hour, minute, second, nanosecond
Tuple Fields
0: TimeImplementations
Sourceimpl Time
impl Time
Sourcepub fn create(
hour: u8,
minute: u8,
second: u8,
subsecond: u32,
) -> Result<Box<Time>, CalendarError>
pub fn create( hour: u8, minute: u8, second: u8, subsecond: u32, ) -> Result<Box<Time>, CalendarError>
Creates a new Time given field values
Sourcepub fn from_string(v: &DiplomatStr) -> Result<Box<Time>, Rfc9557ParseError>
pub fn from_string(v: &DiplomatStr) -> Result<Box<Time>, Rfc9557ParseError>
Creates a new Time from an IXDTF string.
Sourcepub fn start_of_day() -> Result<Box<Time>, CalendarError>
pub fn start_of_day() -> Result<Box<Time>, CalendarError>
Creates a new Time representing the start of the day (00:00:00.000).